@@ -16,32 +16,25 @@ register_admin_task(
     }
 );
 
+# just to note a problem with this query:
+# using DeviceSkip to see if discover is blocked, but that table only shows
+# blocked actions on backends not permitted, so there may be a backend running
+# that permits the action, we would not know.
+
 get '/ajax/content/admin/undiscoveredneighbors' => require_role admin => sub {
     my @results
         = schema('netdisco')->resultset('Virtual::UndiscoveredNeighbors')->hri->all;
     return unless scalar @results;
 
-    # Don't include devices excluded from discovery by config
-    my @discoverable_results = ();
-    foreach my $r (@results) {
-      # create a new row object to avoid hitting the DB in get_device()
-      my $dev = schema('netdisco')->resultset('Device')->new({ip => $r->{remote_ip}});
-      next unless is_discoverable( $dev, $r->{remote_type} );
-      next if (not setting('discover_waps')) and $r->{remote_is_wap};
-      next if (not setting('discover_phones')) and $r->{remote_is_phone};
-      push @discoverable_results, $r;
-    }
-    return unless scalar @discoverable_results;
-
     if ( request->is_ajax ) {
         template 'ajax/admintask/undiscoveredneighbors.tt',
-            { results => \@discoverable_results, },
+            { results => \@results, },
             { layout  => undef };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
         template 'ajax/admintask/undiscoveredneighbors_csv.tt',
-            { results => \@discoverable_results, },
+            { results => \@results, },
             { layout  => undef };
     }
 };
